# Fabric MCP Server Product Requirements Document (PRD)

- [1. Goal, Objective and Context](./1-goal-objective-and-context.md)
  - [Goal](./1-goal-objective-and-context.md#goal)
  - [Objective](./1-goal-objective-and-context.md#objective)
  - [Context](./1-goal-objective-and-context.md#context)
- [2. Functional Requirements (MVP)](./2-functional-requirements-mvp.md)
- [3. Non Functional Requirements (MVP)](./3-non-functional-requirements-mvp.md)
- [4. User Interaction and Design Goals](./4-user-interaction-and-design-goals.md)
  - [A. Developer Experience (DX) Goals (for MCP Client Developers)](./4-user-interaction-and-design-goals.md#a-developer-experience-dx-goals-for-mcp-client-developers)
  - [B. Operational Design Goals (for Server Administrators/Users)](./4-user-interaction-and-design-goals.md#b-operational-design-goals-for-server-administratorsusers)
- [5. Technical Assumptions](./5-technical-assumptions.md)
  - [Testing requirements](./5-technical-assumptions.md#testing-requirements)
- [Epic Overview](./epic-overview/index.md)
  - [Epic 1: Foundational Server Setup & Basic Operations](./epic-overview/epic-1-foundational-server-setup-basic-operations.md)
  - [Epic 2: Fabric Pattern Discovery & Introspection](./epic-overview/epic-2-fabric-pattern-discovery-introspection.md)
  - [Epic 3: Core Fabric Pattern Execution with Strategy & Parameter Control](./epic-overview/epic-3-core-fabric-pattern-execution-with-strategy-parameter-control.md)
  - [Epic 4: Fabric Environment & Configuration Insights](./epic-overview/epic-4-fabric-environment-configuration-insights.md)
- [6. Key Reference Documents](./6-key-reference-documents.md)
- [7. Out of Scope Ideas Post MVP](./7-out-of-scope-ideas-post-mvp.md)
- [8. Change Log](./8-change-log.md)
